@@ -3,7 +3,9 @@ from .consumer import Consumer
 from .matchers import EachLike, Like, SomethingLike, Term, Format
 from .pact import Pact
 from .provider import Provider
+from .verifier import Verifier
+
 from .__version__ import __version__  # noqa: F401
 
 __all__ = ('Consumer', 'EachLike', 'Like', 'Pact', 'Provider', 'SomethingLike',
-           'Term', 'Format')
+           'Term', 'Format', 'Verifier')
