@@ -3,6 +3,14 @@ import os
 from os.path import join, dirname, normpath
 
 
+def broker_client_exe():
+    """Get the appropriate executable name for this platform."""
+    if os.name == 'nt':
+        return 'pact-broker.bat'
+    else:
+        return 'pact-broker'
+
+
 def mock_service_exe():
     """Get the appropriate executable name for this platform."""
     if os.name == 'nt':
@@ -19,6 +27,9 @@ def provider_verifier_exe():
         return 'pact-provider-verifier'
 
 
+BROKER_CLIENT_PATH = normpath(join(
+    dirname(__file__), 'bin', 'pact', 'bin', broker_client_exe()))
+
 MOCK_SERVICE_PATH = normpath(join(
     dirname(__file__), 'bin', 'pact', 'bin', mock_service_exe()))
 
